@@ -6,6 +6,7 @@
 import time
 import struct
 from collections import deque, Mapping
+from functools import wraps
 import inspect
 import copy
 
@@ -28,7 +29,7 @@ console = getConsole()
 class Act(object):
     """ Container class for actor resolve time initialization and runtime operation """
     __slots__ = ('frame', 'context', 'act',
-                 'actor', 'registrar', 'parms', 'inits', 'ioinits', 'action')
+                 'actor', 'registrar', 'parms', 'inits', 'ioinits')
 
     def __init__(self, frame=None, context=None, act=None, actor=None, registrar=None,
                  parms=None, inits=None, ioinits=None, action='', **kwa ):
@@ -44,7 +45,6 @@ class Act(object):
             .parms = dictionary of keyword arguments for Actor instance call
             .inits = dictionary of arguments to Actor.__init__()
             .ioinits = dictionary of arguments to Actor.initio()
-            .action = string name of Actor method to call
         """
         super(Act,self).__init__()
 
@@ -53,10 +53,9 @@ class Act(object):
         self.act = act
         self.actor = actor #callable instance performs action
         self.registrar = registrar or Actor
-        self.parms = parms or odict()       
-        self.inits = inits or odict()
-        self.ioinits = ioinits or odict()
-        self.action = action # default call
+        self.parms = parms or odict() # parms must always be a dict
+        self.inits = inits if inits else None # store None if empty dict
+        self.ioinits = ioinits if ioinits else None # store None if empty dict
 
     def __call__(self): #make Act instance callable as function
         """ Define act as callable object """
@@ -78,17 +77,34 @@ class Act(object):
         
         if not isinstance(self.actor, Actor): # Need to resolve .actor
             actor, inits, ioinits = self.registrar.__fetch__(self.actor)
-            inits.update(self.inits)
+            inits.update(self.inits or odict())
             if 'name' not in inits:
                 inits['name'] = self.actor
             inits['store'] = self.frame.store
             inits['act'] = self
-            self.actor = actor(**inits)
-            self.ioinits.create(ioinits) #fill in defaults
+            self.actor = actor = actor(**inits)
             
-        parms = self.actor.resolve(**self.parms)
-        self.parms.update(parms)
-        self.actor.postinitio(**self.parms)
+            ioinits.update(self.ioinits or odict())
+            if ioinits:
+                iois = actor.initio(**ioinits)
+                if iois:
+                    for key, ioi in iois.items():
+                        share = actor.resolvePath(   ipath=ioi['ipath'],
+                                                     ival=ioi.get('ival'), 
+                                                     iown=ioi.get('iown'))
+                        if actor._Parametric:
+                            if key in self.parms:
+                                msg = "ResolveError: Parm and Ioi with same name"
+                                raise excepting.ResolveError(msg, key, self)
+                            self.parms[key] = share                            
+                        else:
+                            if hasattr(actor, key):
+                                msg = "ResolveError: Attribute and Ioi with same name"
+                                raise excepting.ResolveError(msg, key, self) 
+                            setattr(actor, key, share)                  
+            
+            self.parms.update(self.actor.resolve(**self.parms))
+            self.actor.postinitio(**self.parms)
             
     def clone(self, clones):
         """ Return clone of self in support of framer cloning
@@ -111,7 +127,7 @@ class Nact(Act):
     """ Negating Act used for actor needs to give Not Need
     """
     __slots__ = ('frame', 'context', 'act',
-                 'actor', 'registrar', 'parms', 'inits', 'ioinits', 'action')
+                 'actor', 'registrar', 'parms', 'inits', 'ioinits')
 
     def __init__(self, **kwa ):
         """ Initialization method for instance. """
@@ -130,32 +146,92 @@ class Nact(Act):
         if self.actor:
             self.actor.expose()
 
+class SideAct(Act):
+    """ Anciliary act to a main Act/Actor used to call a different 'action' method
+        of the Main act.actor in support of combined activity such as restarting
+        an action.
+        
+        SideActa are created in the .resolve method of an Actor and assume that
+        all attributes and parms have already been resolved.
+        
+        Unique Attributes:
+            .action = name of method to call in .actor 
+    """
+    __slots__ = ('action')
+
+    def __init__(self, action='', **kwa ):
+        """ Initialization method for instance. """
+        super(SideAct, self).__init__(**kwa)
+        self.action = action
+        
+    def __call__(self): #make Act instance callable as function
+        """ Define call method named .action of .actor """
+        return (getattr(self.actor, self.action)(**self.parms))
+
+    def resolve(self, **kwa):
+        """ Assumes all has been resolved.
+            Check for valid action
+        """
+        if not isinstance(self.actor, Actor): # Woops
+            msg = "ResolveError: Unresolved actor"
+            raise excepting.ResolveError(msg, self.actor, self)
+        
+        if not self.action : # Woops
+            msg = "ResolveError: Empty action"
+            raise excepting.ResolveError(msg, self.action, self)
+        
+        if not getattr(self.actor, self.action, None):
+            msg = "ResolveError: Missing action in actor"
+            raise excepting.ResolveError(msg, self.action, self)
+        
+def actorify(name, base=None, registry=None, inits=None, ioinits=None, parametric=None):
+    """ Parametrized decorator function that converts the decorated function
+        into an Actor sub class with .action method and with class name that
+        is the reverse camel case of name and registers the
+        new subclass in the registry under name.
+        If base is not provided then use Actor
+        
+        The parameters  registry, parametric, inits, and ioinits if provided,
+        are used to create the class attributes for the new subclass
+        
+    """
+    base = base or Actor
+    if not issubclass(base, Actor):
+        msg = "Base class '{0}' not subclass of Actor".format(base)
+        raise excepting.RegisterError(msg)
+    
+    name = aiding.reverseCamel(name, lower=False) 
+    
+    attrs = odict()
+    if registry:
+        attrs(Registry=odict())
+    if parametric is not None:
+        attrs(_Parametric=parametric)
+    if inits:
+        attrs['Inits'] = odict(inits)
+    if ioinits:
+        attrs['Ioinits'] = odict(ioinits)
+    cls = type(name, (base, ), attrs )
+    
+    def implicit(func):
+        @wraps(func)
+        def inner(*pa, **kwa):
+            return func(*pa, **kwa)
+        cls.action = inner
+        return inner
+    return implicit    
+
 class Actor(object): # old registering.StoriedRegistry
     """ Actor Base Class
         Has Actor specific Registry of classes
     """
     __metaclass__ = registering.RegisterType
     Registry = odict() # Actor Registry
+    Inits = odict() # class defaults support for 
     Ioinits = odict() # class defaults
     _Parametric = True # Convert iois to action method parameters if Truthy
     __slots__ = ('name', 'store', 'act')
     
-    @classmethod
-    def actify(cls, name, parms=None, inits=None, ioinits=None):
-        """ Return new Act using the class specific registry to get Actor class
-            from name and defaults for parms, inits, and ioinits
-            Updates defaults with passed in parms, inits, ioinits
-        """
-        inits = inits or odict()
-        ioinits = ioinits or odict()
-        # fetch actor and default copies of inits and ioinits from registry
-        actor, rinits, rioinits = cls.__fetch__(name)
-        inits.create(rinits) # set defaults of missing
-        if 'name' not in inits:
-            inits['name'] = name
-        ioinits.create(rioinits) # set defaults of missing
-        return Act(actor=actor, parms=parms, inits=inits, ioinits=ioinits)
-    
     def __init__(self, name='', store=None, act=None, **kwa ):
         """ Initialization method for instance.
 
@@ -192,23 +268,7 @@ class Actor(object): # old registering.StoriedRegistry
             share refs and update parms
         """
         parms = odict()
-        if self.act.ioinits:
-            iois = self.initio(**self.act.ioinits)
-            if iois:
-                for key, ioi in iois.items():
-                    share = self.resolvePath(    ipath=ioi['ipath'],
-                                                 ival=ioi.get('ival'), 
-                                                 iown=ioi.get('iown'))
-                    if self._Parametric:
-                        if key in kwa:
-                            msg = "ResolveError: Parm and Ioi with same name"
-                            raise excepting.ResolveError(msg, key, self)
-                        parms[key] = share                            
-                    else:
-                        if hasattr(self, key):
-                            msg = "ResolveError: Attribute and Ioi with same name"
-                            raise excepting.ResolveError(msg, key, self) 
-                        setattr(self, key, share)                            
+                              
         return parms    
     
     def initio(self, inode='', **kwa):
@@ -512,7 +572,7 @@ class Interrupter(Actor):
        processing and result in a change in the frame or the frame processing.
 
        This class must be subclassed. This is a convenience so can either use
-         isinstance to test or has_attr interruptive
+         isinstance to test
 
        Specifically and Interrupter's action() method returns truthy when its action
        will interrupt the normal frame processing examples are
@@ -522,14 +582,10 @@ class Interrupter(Actor):
 
 
     """
-    __slots__ = ('_interruptive', )
-    
     def __init__(self,**kw ):
         """Initialization method for instance. """
         super(Interrupter,self).__init__(**kw)
 
-        self._interruptive = None
-
 class Transiter(Interrupter):
     """Transiter Interrupter Actor Patron Registry Class 
        Transiter  is a special actor that performs transitions between frames
@@ -656,9 +712,6 @@ class Suspender(Interrupter):
           which truncates the active outline effectively suspended the truncated
           frames
 
-       Instance Attributes
-          ._activative = flag which indicates this actor's action returns conditional aux
-
        Parameters
             needs = list of Act objects that are exit needs for this trans
             main = source frame of trans
@@ -666,12 +719,9 @@ class Suspender(Interrupter):
             human = text version of transition
 
     """
-    __slots__ = ('_activative',)
-    
     def __init__(self,**kw ):
         """Initialization method for instance. """
         super(Suspender,self).__init__(**kw)
-        self._activative = None
 
     def action(self, needs, main, aux, human, **kw):
         """Action called by Actor  """
@@ -724,7 +774,13 @@ class Suspender(Interrupter):
     def expose(self):
         """      """
         console.terse("Suspender {0}\n".format(self.name))
-
+    
+    def deactivize(self, aux, **kwa):
+        """ If not aux.done Then force deactivate. Used in exit action."""
+        if not aux.done:
+            console.profuse("{0} deactivate {1}\n".format(self.name, aux.name))
+            self.deactivate(aux)             
+        
     def deactivate(self, aux):
         """Called by deactivator actor to cleanly exit      """
         console.profuse("Deactivating {0}\n".format(aux.name))
@@ -756,6 +812,14 @@ class Suspender(Interrupter):
         for act in needs:
             act.act = self.act
             act.resolve()
+        
+        deActParms = dict(aux=aux)
+        deAct = SideAct( actor=self,
+                        parms=deActParms,
+                        action='deactivize')              
+        self.act.frame.addExact(deAct)
+        console.profuse("     Added Exact {0} with {1}\n".format(deAct.actor, deAct.parms))
+        deAct.resolve()
 
         return parms    
 
@@ -795,78 +859,7 @@ class Suspender(Interrupter):
         
         return parms
 
-class Deactivator(Actor):
-    """Deactivator Actor Patron Registry Class 
 
-       Deactivator is a special actor that acts on an Act
-
-       In the Deactivator's action method, 
-          IF the act passed in as a parameter .actor has an _activate attribute THEN
-                       it calls the deactivate method its .actor
-       This is to ensure the outline in cond aux is exited cleanly when the aux
-          is preempted by higher level transition.
-
-       Builder adds a deactivator for each Suspender preact
-    """
-    def action(self, act, aux, **kw):
-        """Action called by Actor
-        """
-        #console.profuse("{0} action {1} for {2}\n".format(self.name, actor.name, aux.name))
-
-        if hasattr(act.actor, '_activative') and not aux.done:
-            console.profuse("{0} deactivate {1} for {2}\n".format(self.name, act.actor.name, aux.name))
-            return act.actor.deactivate(aux)
-
-    def expose(self):
-        """   """
-        console.terse("Deactivator {0}\n".format(self.name))
-    
-    def resolve(self, aux, **kwa):
-        """Resolve aux link parm"""
-        parms = super(Deactivator, self).resolve( **kwa) 
-
-        if not isinstance(aux, framing.Framer):
-            if aux not in framing.Framer.Names:
-                raise excepting.ResolveError("ResolveError: Bad aux link",
-                                                             aux, self.name)                
-            parms['aux'] = aux = framing.Framer.Names[aux] #replace name with valid link
-            console.terse("    Resolved aux as {0}".format(aux.name))
-
-        if aux.schedule != AUX:
-            msg = "ResolveError: Bad deactivator aux link not scheduled as AUX"
-            raise excepting.ResolveError(msg, aux.name, self.name)
-
-        return parms    
-        
-    def cloneParms(self, parms, clones, **kw):
-        """ Returns parms fixed up for framing cloning. This includes:
-            Reverting any Frame links to name strings,
-            Reverting non cloned Framer links into name strings
-            Replacing any cloned framer links with the cloned name strings from clones
-            Replacing any parms that are acts with clones.
-            
-            clones is dict whose items keys are original framer names
-            and values are duples of (original,clone) framer references
-        """
-        parms = super(Deactivator,self).cloneParms(parms, clones, **kw)
-        
-        actor = parms.get('actor')
-        aux = parms.get('aux')
-        
-        if isinstance(aux, framing.Framer):
-            parms['aux'] = aux.name # revert to name
-        
-        if isinstance(aux, framing.Framer):
-            if aux.name in clones:
-                parms['aux'] = clones[aux.name][1].name
-            else:
-                parms['aux'] = aux.name # revert to name
-        elif aux: # assume namestring
-            if aux in clones:
-                parms['aux'] = clones[aux][1].name        
-
-        return parms
-              
 class Restarter(Actor):
     """ Restarter is a special actor that acts on other act's actor
         In the Restarter's action method, 
